from typing import Literal

TransitionProperty = Literal[
    'none',
    'all',
    '',
    'colors',
    'opacity',
    'shadow',
    'transform',
]
